<h1 align="center">
<img src="https://raw.githubusercontent.com/paul02prof/pyverif/master/P-removebg-preview.png" width="450" height="200">
</h1>

PyVerif is a  package for form checking with Python.


- **Documentation:** https://github.com/paul02prof/pyverif/blob/master/README.md
- **Source code:** https://github.com/paul02prof/pyverif
- **Bug reports:** https://github.com/paul02prof/pyverif/issues

It provides:

- a powerful checking system
- sophisticated  functions
